@@ -5,7 +5,7 @@ use warnings;
 
 use 5.010;
 
-use parent qw/Exporter Class::Accessor::Fast/;
+use parent qw{ Exporter Class::Accessor::Fast };
 
 __PACKAGE__->follow_best_practice;
 
@@ -35,6 +35,9 @@ __PACKAGE__->mk_accessors(
     _session_token
     session_token_required
     source
+    sso_role_name
+    sso_account_id
+    sso_region
     timeout
     user_agent
   }
@@ -92,7 +95,7 @@ use constant { ## no critic (ValuesAndExpressions::ProhibitConstantPragma, Namin
   X_AMZ_SSO_BEARER_TOKEN        => ':x-amz-sso_bearer_token',
 };
 
-our $VERSION = '1.1.10'; ## no critic (ValuesAndExpressions::RequireInterpolationOfMetachars)
+our $VERSION = '1.1.11'; ## no critic (ValuesAndExpressions::RequireInterpolationOfMetachars)
 
 our @EXPORT_OK
   = qw{ create_passkey set_sso_credentials get_role_credentials };
@@ -140,6 +143,17 @@ sub new {
         . "!! Credentials may be exposed in debug messages !!\n" );
   } ## end if ( $self->get_insecure)
 
+  # if the caller wants us to use his SSO credentials
+  if ( $self->get_sso_role_name && $self->get_sso_account_id ) {
+    my $region = $self->get_sso_region || $self->get_region;
+
+    set_sso_credentials( $self->get_sso_role_name, $self->get_sso_account_id,
+      $region );
+
+    # we'll set them from the environment below
+    $self->set_order( ['env'] );
+  }
+
   if ( !$options->{'aws_secret_access_key'}
     || !$options->{'aws_access_key_id'} ) {
     $self->set_credentials;
@@ -157,10 +171,9 @@ sub new {
   } ## end else [ if ( !$options->{'aws_secret_access_key'...})]
 
   if ( !$self->get_region ) {
-    $self->set_region( $ENV{'AWS_REGION'}
-        || $ENV{'AWS_DEFAULT_REGION'}
+    $self->set_region( $self->get_region_from_env
         || $self->get_default_region );
-  } ## end if ( !$self->get_region)
+  }
 
   return $self;
 } ## end sub new
@@ -198,6 +211,16 @@ sub reset_credentials {
   return $self;
 } ## end sub reset_credentials
 
+########################################################################
+sub get_region_from_env {
+########################################################################
+  my ($self) = @_;
+
+  my $region = $ENV{'AWS_REGION'} || $ENV{'AWS_DEFAULT_REGION'};
+
+  return $region;
+}
+
 ########################################################################
 sub get_default_region {
 ########################################################################
@@ -468,7 +491,7 @@ sub get_region_from_config {
     $region = $ini->{'default'}->{'region'};
   } ## end if ( $ini->{'default'})
 
-  $self->get_logger->debug( "default region: " . $region // 'undef' );
+  $self->get_logger->debug( 'default region: ' . $region // 'undef' );
 
   return $region;
 } ## end sub get_region_from_config
@@ -1090,7 +1113,7 @@ sub set_sso_credentials {
       }
     ) {
 
-      $ENV{ $p->[1] } = $credentials->{ $p->[0] };
+      $ENV{ $p->[1] } = sprintf '%s', $credentials->{ $p->[0] }; ## no critic (Variables::RequireLocalizedPunctuationVars)
     }
 
   }
@@ -1509,17 +1532,24 @@ you only want to retrieve the credentials use C<get_role_credentials>.
  set_sso_credentials($role_name, $account_id, $region);
  my $credentials = Amazon::Credentials->new;
 
- my $credential = get_role_credentials(role_name  => $role_name,
-                                       account_id => $account_id,
-                                       region     => $region);
+ my $credential = get_role_credentials(role_name  => $sso_role_name,
+                                       account_id => $sso_account_id,
+                                       region     => $sso_region);
 
 or from the command line...
 
  amazon-credentials.sh --role my-sso-role --account 01234567890
 
+or pass your SSO role name and account ID...
+
+ my $credentials =  Amazon::Credentials->new(sso_role_name  => $role,
+                                             sso_account_id => $account_id,
+                                             sso_region     => $region,
+                                            );
+ 
 =head1 VERSION
 
-This document reverse to verion 1.1.10 of
+This document reverse to verion 1.1.11 of
 C<Amazon::Credentials>.
 
 =head1 METHODS AND SUBROUTINES
@@ -1928,12 +1958,12 @@ C<options> is a hash (not reference) of options
 
 =item account_id => AWS account id (required)
 
-required
-
-=ite region => AWS region 
+=item region => AWS region where SSO has been provisioned
 
 default: $ENV{AWS_REGION}, $ENV{AWS_DEFAULT_REGION}, us-east-1
 
+=back
+
 =head2 set_sso_credentials
 
  set_sso_options(role-name, account-id, region)
